@@ -109,11 +109,18 @@ def fetch_delayed_crypto_daily_data(frequence = 'daily', ssj=None, local_root_di
     daily_crypto_df.to_pickle(saving_return_path)
     return daily_crypto_df
 
-
-
-def fetch_crypto_daily_data(ssj=None, local_root_directory=None, daily_return_pkl_filename_suffix='_daily_returns.pkl', refetch_all=True,daily_crypto_starting_day='2012-01-01', daily_crypto_ending_day=None,ssj_against='USDT', exchange = 'binance', saving =False):
+def fetch_crypto_daily_data(ssj=None, local_root_directory=None, daily_return_pkl_filename_suffix='_daily_returns.pkl', refetch_all=True,daily_crypto_starting_day='2012-01-01', daily_crypto_ending_day=None,ssj_against='USDT', exchange = None, saving =False):
     dates_stub = daily_crypto_starting_day.strftime('%d_%b_%Y') + '_' + daily_crypto_ending_day.strftime('%d_%b_%Y')
     pickle_saving_path = local_root_directory+ssj+'_'+dates_stub+daily_return_pkl_filename_suffix
+    if not refetch_all:
+        try:
+            print(f'reading {pickle_saving_path}')
+            dataframe = pd.read_pickle(pickle_saving_path)
+            return dataframe
+        except Exception as e:
+            print(f'trouble {e}')
+            refetch_all = True
+
     if refetch_all:
         year = datetime.datetime.now().year
         month = datetime.datetime.now().month
@@ -130,7 +137,11 @@ def fetch_crypto_daily_data(ssj=None, local_root_directory=None, daily_return_pk
         ts8 = ts7 - 2001 * 3600 * 24
 
         print('Loading data')
-        day_url_request = 'https://min-api.cryptocompare.com/data/histoday?fsym={}&tsym='+ssj_against+'&toTs={}&limit=2000'
+        if exchange is None:
+            day_url_request = 'https://min-api.cryptocompare.com/data/v2/histoday?fsym={}&tsym='+ssj_against+'&toTs={}&limit=2000'
+        else :
+            day_url_request = 'https://min-api.cryptocompare.com/data/v2/histoday?fsym={}&tsym='+ssj_against+'&e='+exchange+'&toTs={}&limit=2000'
+
         dataframe = None
         for me_timestamp in [ts8,ts7,ts6,ts5,ts4,ts3,ts2,ts1,ts]:
             print('waiting')
@@ -376,8 +387,7 @@ def fetch_local_crypto_hourly_data(ssj=None, local_root_directory=None, hourly_r
     dataframe.to_pickle(pickle_saving_path)
     return dataframe
 
-
-def fetch_crypto_hourly_data(ssj=None, local_root_directory=None, hourly_return_pkl_filename_suffix='_hourly_returns.pkl',refetch_all=True, daily_crypto_starting_day='2012-01-01', daily_crypto_ending_day=None, ssj_against='USDT', exchange = 'binance', save_to_disk = False):
+def fetch_crypto_hourly_data(ssj=None, local_root_directory=None, hourly_return_pkl_filename_suffix='_hourly_returns.pkl',refetch_all=True, daily_crypto_starting_day='2012-01-01', daily_crypto_ending_day=None, ssj_against='USDT', exchange = None, save_to_disk = False):
     dates_stub = daily_crypto_starting_day.strftime('%d_%b_%Y') + '_' + daily_crypto_ending_day.strftime('%d_%b_%Y')
     pickle_saving_path = local_root_directory + ssj + '_' + dates_stub + hourly_return_pkl_filename_suffix
 
@@ -407,8 +417,11 @@ def fetch_crypto_hourly_data(ssj=None, local_root_directory=None, hourly_return_
         ts18 = ts17 - 2001 * 3600
 
         print('Loading data')
-        #hours_url_request = 'https://min-api.cryptocompare.com/data/histohour?fsym={}&tsym=' + ssj_against + '&e=' + exchange + '&toTs={}&limit=2000'
-        hours_url_request = 'https://min-api.cryptocompare.com/data/histohour?fsym={}&tsym=' + ssj_against + '&toTs={}&limit=2000'
+        if exchange is None:
+            hours_url_request = 'https://min-api.cryptocompare.com/data/v2/histohour?fsym={}&tsym=' + ssj_against + '&toTs={}&limit=2000'
+        else :
+            hours_url_request = 'https://min-api.cryptocompare.com/data/v2/histohour?fsym={}&tsym=' + ssj_against + '&e=' + exchange + '&toTs={}&limit=2000'
+
         dataframe = None
         for me_timestamp in [ts18, ts17, ts16, ts15, ts14, ts13, ts12, ts11, ts10, ts9, ts8, ts7, ts6, ts5, ts4, ts3, ts2, ts1, ts]:
             print('waiting')
@@ -437,70 +450,6 @@ def fetch_crypto_hourly_data(ssj=None, local_root_directory=None, hourly_return_
             dataframe.to_pickle(pickle_saving_path)
     else:
         dataframe = pd.read_pickle(pickle_saving_path)
-
-def fetch_crypto_hourly_data(ssj=None, local_root_directory=None, hourly_return_pkl_filename_suffix='_hourly_returns.pkl',refetch_all=True, daily_crypto_starting_day='2012-01-01', daily_crypto_ending_day=None, ssj_against='USDT', exchange = 'binance', save_to_disk = False):
-    dates_stub = daily_crypto_starting_day.strftime('%d_%b_%Y') + '_' + daily_crypto_ending_day.strftime('%d_%b_%Y')
-    pickle_saving_path = local_root_directory + ssj + '_' + dates_stub + hourly_return_pkl_filename_suffix
-
-    if refetch_all:
-        year = datetime.datetime.now().year
-        month = datetime.datetime.now().month
-        day = datetime.datetime.now().day
-        hour = datetime.datetime.utcnow().hour
-        ts = datetime.datetime(year, month, day, tzinfo=datetime.timezone.utc).timestamp() + hour * 3600
-        ts1 = ts - 2001 * 3600
-        ts2 = ts1 - 2001 * 3600
-        ts3 = ts2 - 2001 * 3600
-        ts4 = ts3 - 2001 * 3600
-        ts5 = ts4 - 2001 * 3600
-        ts6 = ts5 - 2001 * 3600
-        ts7 = ts6 - 2001 * 3600
-        ts8 = ts7 - 2001 * 3600
-        ts9 = ts8 - 2001 * 3600
-        ts10 = ts9 - 2001 * 3600
-        ts11 = ts10 - 2001 * 3600
-        ts12 = ts11 - 2001 * 3600
-        ts13 = ts12 - 2001 * 3600
-        ts14 = ts13 - 2001 * 3600
-        ts15 = ts14 - 2001 * 3600
-        ts16 = ts15 - 2001 * 3600
-        ts17 = ts16 - 2001 * 3600
-        ts18 = ts17 - 2001 * 3600
-
-        print('Loading data')
-        #hours_url_request = 'https://min-api.cryptocompare.com/data/histohour?fsym={}&tsym=' + ssj_against + '&e=' + exchange + '&toTs={}&limit=2000'
-        hours_url_request = 'https://min-api.cryptocompare.com/data/histohour?fsym={}&tsym=' + ssj_against + '&toTs={}&limit=2000'
-        dataframe = None
-        for me_timestamp in [ts18, ts17, ts16, ts15, ts14, ts13, ts12, ts11, ts10, ts9, ts8, ts7, ts6, ts5, ts4, ts3, ts2, ts1, ts]:
-            print('waiting')
-            time.sleep(1)
-            df = request_hour_data_paquet(hours_url_request, me_timestamp, ssj)
-            if df is not None:
-                if dataframe is not None:
-                    dataframe = dataframe.append(df, ignore_index=True)
-                else:
-                    dataframe = df.copy()
-
-        dataframe['time'] = pd.to_datetime(dataframe['time'], unit='s')
-        dataframe = dataframe.sort_values(by=['time'])
-        dataframe = dataframe.rename(columns={"time": "date"}, errors="raise")
-        dataframe = dataframe.set_index(dataframe['date'])
-        dataframe = dataframe.drop(columns=['date','volumefrom', 'conversionType', 'conversionSymbol' ])
-
-        dataframe = dataframe.rename(columns ={'volumeto':'volume'})
-
-        print('size fetched')
-        print(dataframe.shape)
-        dataframe = dataframe[dataframe.index >= daily_crypto_starting_day]
-        print('size filtered after '+str(daily_crypto_starting_day))
-        print(dataframe.shape)
-        if save_to_disk:
-            dataframe.to_pickle(pickle_saving_path)
-    else:
-        dataframe = pd.read_pickle(pickle_saving_path)
-
-
-
     return dataframe
 
 def fetch_crypto_tuple_hourly_data(ssj=None, pickle_saving_path=None, refetch_all=True, frequency=4):
