@@ -15,13 +15,9 @@ from sklearn.metrics import accuracy_score
 from functools import partial
 
 import hashlib
-from cryptotoolbox.utility import date_utility
 import pandas as pd
 import numpy as np
 
-from datetime import timedelta, date
-from numba import njit, jit, types, typed
-from numba.typed import Dict,List
 
 
 def get_readable_label(signal_parameters):
@@ -33,7 +29,7 @@ def get_readable_label(signal_parameters):
 
 
 def unjsonize_list_run_results(local_root_directory, list_pkl_file_name):
-    signals_list = napoleon_connector.load_pickled_list(local_root_directory=local_root_directory,
+    signals_list = crypto_connector.load_pickled_list(local_root_directory=local_root_directory,
                                                              list_pkl_file_name=list_pkl_file_name)
     print('signals list size '+str(len(signals_list)))
     params_list = []
@@ -192,7 +188,7 @@ def f_sharpe_signals_mix(data, w, display_threshold = 0.99, period = 252):
     return -sharpe_strat
 
 
-@njit()
+#@njit()
 def numba_rolling_zscore(signal_np_array, roll_size, skipping_point=5):
     me_zscore_expanding_array = np.zeros(signal_np_array.shape)
     for i in range(len(signal_np_array)):
@@ -204,7 +200,7 @@ def numba_rolling_zscore(signal_np_array, roll_size, skipping_point=5):
     return me_zscore_expanding_array
 
 
-@njit()
+#@njit()
 def numba_expanding_zscore(signal_np_array, skipping_point):
     me_zscore_expanding_array = np.zeros(signal_np_array.shape)
     for i in range(len(signal_np_array)):
